"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var usePressAndDrag_exports = {};
__export(usePressAndDrag_exports, {
  usePressAndDrag: () => usePressAndDrag
});
module.exports = __toCommonJS(usePressAndDrag_exports);
var import_useDrag = require("@workwave-tidal/core/hooks/useDrag");
var import_react = require("react");
const MAX_PROGRESS_MS = 1e3;
const defaultAcceptDragEvent = () => true;
function usePressAndDrag(props) {
  const {
    longPressDelayMilliseconds = 220,
    longPressDurationMilliseconds = 500,
    acceptDragEvent = defaultAcceptDragEvent,
    draggable,
    open,
    fabPosition = "bottom-right",
    onDragStart
  } = props;
  const acceptEvent = (0, import_react.useCallback)(
    (e) => {
      if (!draggable || open) return false;
      return acceptDragEvent(e);
    },
    [acceptDragEvent, draggable, open]
  );
  const { dragInfo, dispatch } = (0, import_useDrag.useDrag)({ persist: true });
  const { dragging, cssTransform } = dragInfo;
  const [progressMs, setProgressMs] = (0, import_react.useState)(0);
  const progressHistoryRef = (0, import_react.useRef)([]);
  const isMouseDownRef = (0, import_react.useRef)(false);
  const mouseDownTimeMsRef = (0, import_react.useRef)(0);
  const mouseDownEventRef = (0, import_react.useRef)(new MouseEvent("mousedown"));
  const progressZoomScale = 1.16;
  const circularProgressSize = 56;
  const containerSize = Math.floor(circularProgressSize * progressZoomScale);
  const speed = 1 / (longPressDurationMilliseconds / 1e3);
  function updateProgress(timeStampMs) {
    const deltaFromLastAnimationMs = Math.round(timeStampMs - mouseDownTimeMsRef.current);
    const progressMs2 = Math.min(
      Math.max(0, deltaFromLastAnimationMs - longPressDelayMilliseconds) * speed,
      MAX_PROGRESS_MS
    );
    if (isMouseDownRef.current === false) {
      resetProgress();
      return;
    }
    progressHistoryRef.current.push(progressMs2);
    setProgressMs(progressMs2);
    if (progressMs2 < MAX_PROGRESS_MS) {
      requestAnimationFrame(updateProgress);
    }
  }
  function resetProgress() {
    let historyIndex = progressHistoryRef.current.length - 1;
    const animateReset = () => {
      if (isMouseDownRef.current) return;
      if (historyIndex > 0) {
        setProgressMs(progressHistoryRef.current[historyIndex]);
        historyIndex -= 3;
        requestAnimationFrame(animateReset);
      } else {
        setProgressMs(0);
      }
    };
    requestAnimationFrame(animateReset);
  }
  (0, import_react.useEffect)(() => {
    if (progressMs >= MAX_PROGRESS_MS && isMouseDownRef.current && !dragging && mouseDownEventRef.current) {
      if (!acceptEvent(mouseDownEventRef.current)) return;
      const coords = {
        x: mouseDownEventRef.current.clientX,
        y: mouseDownEventRef.current.clientY
      };
      dispatch({ type: "dragStart", payload: { coords } });
      onDragStart?.();
    }
  }, [progressMs, dispatch, dragging, acceptEvent, onDragStart]);
  (0, import_react.useEffect)(() => {
    const controller = new AbortController();
    function mouseMoveHandler(e) {
      if (!dragging) return;
      if (!acceptEvent(e)) return;
      dispatch({
        type: "dragMove",
        payload: {
          coords: {
            x: e.clientX,
            y: e.clientY
          }
        }
      });
    }
    const throttledMouseMoveHandler = throttle(mouseMoveHandler, 16);
    document.addEventListener("mousemove", throttledMouseMoveHandler, { signal: controller.signal });
    return () => {
      controller.abort();
    };
  }, [dispatch, dragging, acceptEvent]);
  function onMouseDown(mouseEvent) {
    if (mouseEvent.button !== 0) return;
    if (!acceptEvent(mouseEvent.nativeEvent)) return;
    setProgressMs(0);
    mouseDownTimeMsRef.current = performance.now();
    isMouseDownRef.current = true;
    progressHistoryRef.current = [];
    requestAnimationFrame(updateProgress);
    mouseDownEventRef.current = mouseEvent.nativeEvent;
  }
  function onMouseUp(mouseEvent) {
    isMouseDownRef.current = false;
    if (!acceptEvent(mouseEvent.nativeEvent)) return;
    if (!dragging) return;
    dispatch({
      type: "dragEnd",
      payload: {
        coords: {
          x: mouseEvent.clientX,
          y: mouseEvent.clientY
        },
        persist: true
      }
    });
    setProgressMs(0);
  }
  function onMouseLeave() {
    isMouseDownRef.current = false;
  }
  const sx = (theme) => ({
    transform: cssTransform,
    cursor: dragging ? "grabbing" : "grab",
    position: "absolute",
    width: containerSize,
    height: containerSize,
    ...createPositionRules(fabPosition, theme.spacing),
    "& > *": {
      position: "absolute",
      top: 0,
      left: 0
    }
  });
  return {
    sx,
    // progress is expected to be between 0 and 100
    progress: Math.round(progressMs / 10),
    progressComplete: progressMs >= MAX_PROGRESS_MS,
    disableBounceAnimation: isMouseDownRef.current,
    progressZoomScale,
    circularProgressSize,
    dragging,
    onMouseDown,
    onMouseUp,
    onMouseLeave
  };
}
function createPositionRules(fabPosition, spacing) {
  switch (fabPosition) {
    case "top-left":
      return {
        top: spacing(2),
        left: spacing(2)
      };
    case "top-right":
      return {
        top: spacing(2),
        right: spacing(2)
      };
    case "bottom-left":
      return {
        bottom: spacing(2),
        left: spacing(2)
      };
    case "bottom-right":
      return {
        bottom: spacing(2),
        right: spacing(2)
      };
    default:
      return {};
  }
}
function throttle(func, limit) {
  let lastCall = 0;
  let timeout = null;
  return function(...args) {
    const now = Date.now();
    if (now - lastCall >= limit) {
      lastCall = now;
      func.apply(this, args);
    } else if (!timeout) {
      const remainingTime = limit - (now - lastCall);
      timeout = setTimeout(() => {
        lastCall = Date.now();
        timeout = null;
        func.apply(this, args);
      }, remainingTime);
    }
  };
}
//# sourceMappingURL=usePressAndDrag.js.map
