"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var useSpeechToText_exports = {};
__export(useSpeechToText_exports, {
  useSpeechToText: () => useSpeechToText
});
module.exports = __toCommonJS(useSpeechToText_exports);
var import_react = require("react");
function useSpeechToText(props) {
  const { onChange, onEnd, onError, onStart } = props;
  const [recording, setRecording] = (0, import_react.useState)(false);
  const recognitionRef = (0, import_react.useRef)(null);
  const allowRecording = (0, import_react.useRef)(Boolean(window.SpeechRecognition || window.webkitSpeechRecognition));
  const onChangeRef = (0, import_react.useRef)(onChange);
  (0, import_react.useEffect)(() => {
    onChangeRef.current = onChange;
  }, [onChange]);
  const onErrorRef = (0, import_react.useRef)(onError);
  (0, import_react.useEffect)(() => {
    onErrorRef.current = onError;
  }, [onError]);
  (0, import_react.useEffect)(() => {
    if (!allowRecording.current) return;
    const recognition = new (window.SpeechRecognition || window.webkitSpeechRecognition)();
    recognitionRef.current = recognition;
    recognition.continuous = true;
    recognition.interimResults = true;
    recognition.onstart = () => setRecording(true);
    recognition.onresult = (event) => {
      let resultText = "";
      let finalText = "";
      for (let i = event.resultIndex; i < event.results.length; i++) {
        if (event.results[i].isFinal) {
          finalText += event.results[i][0].transcript;
        }
        resultText += event.results[i][0].transcript;
      }
      onChangeRef.current?.(resultText, "interim");
      if (finalText) {
        onChangeRef.current?.(finalText, "final");
      }
    };
    recognition.onerror = (event) => {
      onErrorRef.current?.(event);
      setRecording(false);
    };
    recognition.onend = () => setRecording(false);
    return () => {
      recognition.stop();
      recognition.abort();
      recognitionRef.current = null;
    };
  }, []);
  const startRecording = () => {
    recognitionRef.current?.start();
    onStart?.();
  };
  const stopRecording = () => {
    recognitionRef.current?.stop();
    onEnd?.();
  };
  const toggleRecording = () => {
    if (recording) {
      stopRecording();
    } else {
      startRecording();
    }
  };
  if (!allowRecording.current) return false;
  return {
    recording,
    toggleRecording,
    stopRecording,
    startRecording
  };
}
//# sourceMappingURL=useSpeechToText.js.map
