"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var Draggable_exports = {};
__export(Draggable_exports, {
  Draggable: () => Draggable
});
module.exports = __toCommonJS(Draggable_exports);
var import_adapter = require("@atlaskit/pragmatic-drag-and-drop/element/adapter");
var import_react = require("react");
function getPositionFromArgs(args, offset, scale) {
  const { clientX, clientY } = args.location.current.input;
  const { element } = args.source;
  const offsetParent = element.offsetParent ?? element.ownerDocument.body;
  const offsetParentRect = offsetParent.getBoundingClientRect();
  const x = (clientX - offset.x + offsetParent.scrollLeft - offsetParentRect.left) / scale;
  const y = (clientY - offset.y + offsetParent.scrollTop - offsetParentRect.top) / scale;
  return { x, y };
}
function Draggable(props) {
  const { children, disabled, onDrag, onStop, onStart, scale = 1 } = props;
  const [isDragging, setIsDragging] = (0, import_react.useState)(false);
  const rChild = (0, import_react.useRef)(null);
  const rLast = (0, import_react.useRef)({});
  const rDelta = (0, import_react.useRef)({ x: 0, y: 0 });
  const rOffset = (0, import_react.useRef)({ x: 0, y: 0 });
  (0, import_react.useEffect)(() => {
    const handleDragStart = (args) => {
      const { clientX, clientY } = args.location.current.input;
      const { element: element2 } = args.source;
      const elRect = element2.getBoundingClientRect();
      rOffset.current = {
        x: clientX - elRect.left,
        y: clientY - elRect.top
      };
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y
      };
      rLast.current = { x, y };
      setIsDragging(true);
      onStart?.(data);
    };
    const handleDrag = (args) => {
      const { element: element2 } = args.source;
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      rDelta.current = {
        x: x - (rLast.current.x ?? 0),
        y: y - (rLast.current.y ?? 0)
      };
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y,
        lastX: rLast.current.x,
        lastY: rLast.current.y
      };
      rLast.current = { x, y };
      if (rDelta.current.x === 0 && rDelta.current.y === 0) return;
      onDrag?.(data);
    };
    const handleDrop = (args) => {
      const { element: element2 } = args.source;
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      rDelta.current = {
        x: x - (rLast.current.x ?? 0),
        y: y - (rLast.current.y ?? 0)
      };
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y,
        lastX: rLast.current.x,
        lastY: rLast.current.y
      };
      rLast.current = {};
      rOffset.current = { x: 0, y: 0 };
      setIsDragging(false);
      onStop?.(data);
    };
    const element = rChild.current;
    if (!element) return;
    return (0, import_adapter.draggable)({
      element,
      canDrag: () => !disabled,
      onDragStart: handleDragStart,
      onDrag: handleDrag,
      onDrop: handleDrop
    });
  }, [disabled, onStart, onDrag, onStop, scale]);
  (0, import_react.useEffect)(() => {
    const handleDragOver = (e) => {
      e.preventDefault();
      if (!e.dataTransfer) return;
      e.dataTransfer.dropEffect = "move";
    };
    if (!isDragging) return;
    const parentEl = rChild.current?.ownerDocument?.body;
    if (!parentEl) return;
    parentEl.addEventListener("dragover", handleDragOver);
    return () => parentEl.removeEventListener("dragover", handleDragOver);
  }, [isDragging]);
  return (0, import_react.cloneElement)(import_react.Children.only(children), {
    ref: rChild
  });
}
//# sourceMappingURL=Draggable.js.map
