"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var useMasonryItemState_exports = {};
__export(useMasonryItemState_exports, {
  useMasonryItemState: () => useMasonryItemState
});
module.exports = __toCommonJS(useMasonryItemState_exports);
var import_react = require("react");
var import_calculateMasonryItemSize = require("../utils/calculateMasonryItemSize.js");
var import_calculateMasonryItemXY = require("../utils/calculateMasonryItemXY.js");
var import_clamp = require("../utils/clamp.js");
var import_clsx = require("../utils/clsx.js");
var import_getGridColumnWidth = require("../utils/getGridColumnWidth.js");
var import_getMasonryItemPosition = require("../utils/getMasonryItemPosition.js");
var import_getMasonryItemStyle = require("../utils/getMasonryItemStyle.js");
function useMasonryItemState(props) {
  const {
    className: inClassName,
    columns,
    containerPadding,
    containerWidth,
    height,
    id,
    isBounded,
    isDraggable,
    isStatic,
    margin,
    maxRows,
    onDrag,
    onDragStart,
    onDragStop,
    rowHeight,
    transformScale,
    width,
    x,
    y
  } = props;
  const [isDragging, setIsDragging] = (0, import_react.useState)(false);
  const positionParams = (0, import_react.useMemo)(
    () => ({
      columns,
      containerPadding,
      containerWidth,
      margin,
      maxRows,
      rowHeight
    }),
    [columns, containerPadding, containerWidth, margin, maxRows, rowHeight]
  );
  const handleDragStart = (0, import_react.useCallback)(
    (data) => {
      if (!onDragStart) return;
      const { node } = data;
      const newPosition = { top: 0, left: 0 };
      const { offsetParent } = node;
      if (!offsetParent) return;
      const parentRect = offsetParent.getBoundingClientRect();
      const clientRect = node.getBoundingClientRect();
      const clientLeft = clientRect.left / transformScale;
      const parentLeft = parentRect.left / transformScale;
      const clientTop = clientRect.top / transformScale;
      const parentTop = parentRect.top / transformScale;
      newPosition.left = clientLeft - parentLeft + offsetParent.scrollLeft;
      newPosition.top = clientTop - parentTop + offsetParent.scrollTop;
      const { x: x2, y: y2 } = (0, import_calculateMasonryItemXY.calculateMasonryItemXY)(positionParams, newPosition.top, newPosition.left, width, height);
      setIsDragging(true);
      onDragStart(id, x2, y2);
    },
    [onDragStart, transformScale, positionParams, width, height, id]
  );
  const handleDrag = (0, import_react.useCallback)(
    (data) => {
      if (!onDrag) return;
      const { node, deltaX, deltaY } = data;
      let top = data.y;
      let left = data.x;
      if (isBounded) {
        const { offsetParent } = node;
        if (offsetParent) {
          const bottomBoundary = offsetParent.clientHeight - (0, import_calculateMasonryItemSize.calculateMasonryItemSize)(height, rowHeight, margin[1]);
          top = (0, import_clamp.clamp)(top, 0, bottomBoundary);
          const columnWidth = (0, import_getGridColumnWidth.getGridColumnWidth)(positionParams);
          const rightBoundary = containerWidth - (0, import_calculateMasonryItemSize.calculateMasonryItemSize)(width, columnWidth, margin[0]);
          left = (0, import_clamp.clamp)(left, 0, rightBoundary);
        }
      }
      const newPosition = { top, left };
      const { x: x2, y: y2 } = (0, import_calculateMasonryItemXY.calculateMasonryItemXY)(positionParams, top, left, width, height);
      return onDrag(id, x2, y2);
    },
    [isBounded, positionParams, containerWidth, margin, rowHeight, width, height, onDrag, id]
  );
  const handleDragStop = (0, import_react.useCallback)(
    (data) => {
      if (!onDragStop) return;
      const { x: x2, y: y2 } = (0, import_calculateMasonryItemXY.calculateMasonryItemXY)(positionParams, data.y, data.x, width, height);
      setIsDragging(false);
      return onDragStop(id, x2, y2);
    },
    [onDragStop, positionParams, width, height, id]
  );
  const style = (0, import_getMasonryItemStyle.getMasonryItemStyle)((0, import_getMasonryItemPosition.getMasonryItemPosition)(positionParams, x, y, width, height));
  const className = (0, import_clsx.clsx)("react-grid-item", "cssTransforms", inClassName, {
    static: isStatic,
    "react-draggable": isDraggable,
    "react-draggable-dragging": Boolean(isDragging)
  });
  return {
    className,
    handleDragStart,
    handleDrag,
    handleDragStop,
    isDraggable,
    style,
    transformScale
  };
}
//# sourceMappingURL=useMasonryItemState.js.map
