import { jsx } from "react/jsx-runtime";
import {
  createContext,
  useContext,
  useImperativeHandle,
  useMemo,
  useReducer
} from "react";
const conversationApiState = createContext({
  overlayContent: null,
  waitingForResponse: false
});
const conversationApi = createContext({
  setOverlay: () => {
  },
  setWaitingForResponse: () => {
  }
});
function apiReducer(state, action) {
  switch (action.type) {
    case "setOverlayContent":
      return {
        ...state,
        overlayContent: action.children
      };
    case "setWaitingForResponse":
      if (action.value === state.waitingForResponse) return state;
      return {
        ...state,
        waitingForResponse: action.value
      };
    default:
      return state;
  }
}
const initialState = {
  overlayContent: null,
  waitingForResponse: false
};
function useCreateContext() {
  const [state, dispatch] = useReducer(apiReducer, initialState);
  const api = useMemo(
    () => ({
      setOverlay: (children) => {
        dispatch({ type: "setOverlayContent", children });
      },
      setWaitingForResponse: (value) => {
        dispatch({ type: "setWaitingForResponse", value });
      }
    }),
    []
  );
  return { api, state };
}
function ConversationApiProvider(props) {
  const { children, api: apiRef } = props;
  const { api, state } = useCreateContext();
  useImperativeHandle(apiRef, () => api, [api]);
  return /* @__PURE__ */ jsx(conversationApi.Provider, { value: api, children: /* @__PURE__ */ jsx(conversationApiState.Provider, { value: state, children }) });
}
function useConversationApi() {
  return useContext(conversationApi);
}
function useOverlayContent() {
  return useContext(conversationApiState).overlayContent;
}
function useWaitingForResponse() {
  return useContext(conversationApiState).waitingForResponse;
}
export {
  ConversationApiProvider,
  useConversationApi,
  useOverlayContent,
  useWaitingForResponse
};
//# sourceMappingURL=ConversationApiProvider.js.map
