import { jsx, jsxs } from "react/jsx-runtime";
import { Box, useTheme } from "@mui/material";
import { useDrag } from "@workwave-tidal/core/hooks/useDrag";
import { useEffect } from "react";
import { ConversationPanelHandle } from "./components/ConversationPanelHandle.js";
import { useReferenceSize } from "./hooks/useReferenceSize.js";
const disableDragAndDrop = () => false;
function ConversationPanel(props) {
  const {
    sx,
    children,
    fullScreen,
    cornerSize = 14,
    handleSize = 4,
    onChangeSize,
    initialHeight,
    initialWidth,
    minHeight = 0,
    minWidth = 0,
    maxHeight,
    maxWidth,
    hidden,
    fullScreenHorizontalMarginUnits = 6,
    fullScreenVerticalMarginUnits = 20,
    fullScreenElementReference = document.body
  } = props;
  const { spacing } = useTheme();
  const acceptEvent = fullScreen ? disableDragAndDrop : void 0;
  const {
    dragInfo: { offsetX: offsetXCorner, offsetY: offsetYCorner },
    dragRef: dragRefCorner
  } = useDrag({ persist: true, acceptEvent });
  const {
    dragInfo: { offsetY: offsetYTop },
    dragRef: dragRefTop
  } = useDrag({ persist: true, acceptEvent });
  const {
    dragInfo: { offsetX: offsetXLeft },
    dragRef: dragRefLeft
  } = useDrag({ persist: true, acceptEvent });
  const referenceSize = useReferenceSize(fullScreenElementReference);
  const offsetX = offsetXCorner + offsetXLeft;
  const offsetY = offsetYCorner + offsetYTop;
  const width = initialWidth - offsetX;
  const height = initialHeight - offsetY;
  const fullScreenWidth = `calc(${referenceSize.width}px - ${spacing(fullScreenHorizontalMarginUnits)})`;
  const fullScreenHeight = `calc(${referenceSize.height}px - ${spacing(fullScreenVerticalMarginUnits)})`;
  const boxStyle = fullScreen ? { width: fullScreenWidth, height: fullScreenHeight } : { width, height, minHeight, minWidth, maxHeight, maxWidth };
  useEffect(() => {
    if (typeof width === "string" || typeof height === "string") return;
    onChangeSize?.(width, height);
  }, [width, height, onChangeSize]);
  if (hidden) return null;
  return /* @__PURE__ */ jsxs(Box, { sx, position: "relative", display: "flex", style: boxStyle, children: [
    children,
    /* @__PURE__ */ jsx(
      ConversationPanelHandle,
      {
        ref: dragRefCorner,
        sx: {
          width: cornerSize,
          height: cornerSize,
          top: 0,
          left: 0,
          cursor: fullScreen ? "default" : "nwse-resize"
        }
      }
    ),
    /* @__PURE__ */ jsx(
      ConversationPanelHandle,
      {
        ref: dragRefTop,
        sx: {
          height: handleSize,
          top: 0,
          left: 0,
          cursor: fullScreen ? "default" : "ns-resize"
        }
      }
    ),
    /* @__PURE__ */ jsx(
      ConversationPanelHandle,
      {
        ref: dragRefLeft,
        sx: {
          width: handleSize,
          top: 0,
          bottom: 0,
          cursor: fullScreen ? "default" : "ew-resize"
        }
      }
    )
  ] });
}
export {
  ConversationPanel
};
//# sourceMappingURL=ConversationPanel.js.map
