import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { useLexicalComposerContext } from "@lexical/react/LexicalComposerContext";
import { IconButton, Tooltip } from "@mui/material";
import { useEditorData } from "@workwave-tidal/core/components";
import { EditorFooterAction as TidalEditorFooterAction } from "@workwave-tidal/core/components/Editor";
import { WormholeChildren } from "@workwave-tidal/core/hooks";
import { Send } from "@workwave-tidal/core/icons";
import { useEffect, useRef } from "react";
import { useWaitingForResponse } from "../../../ConversationApiProvider.js";
import { useConversationEditorConfigureApi } from "../../../ConversationEditorProvider.js";
import { useConversationTexts } from "../../../LocaleProvider.js";
import { ConversationSuggestionsControls } from "../../../Suggestions/ConversationSuggestionsControls.js";
import { SpeechToTextComponent } from "./components/SpeechToTextComponent.js";
import { useSendAction } from "./hooks/useSendAction.js";
function EditorFooter(props) {
  const { onSend, children, hideSuggestions } = props;
  const texts = useConversationTexts();
  const [editor] = useLexicalComposerContext();
  const { registerEditor } = useConversationEditorConfigureApi();
  useEffect(() => {
    registerEditor(editor);
  }, [editor, registerEditor]);
  const { disabled } = useEditorData();
  const waitingForResponse = useWaitingForResponse();
  const speechToTextApi = useRef(null);
  const handleSend = useSendAction({ onSend, speechToTextApi });
  const disableSendButton = disabled || waitingForResponse;
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(WormholeChildren, { children }),
    /* @__PURE__ */ jsx(TidalEditorFooterAction, { children: /* @__PURE__ */ jsx(ConversationSuggestionsControls, { hidden: hideSuggestions, disabled }) }),
    /* @__PURE__ */ jsx(TidalEditorFooterAction, { children: /* @__PURE__ */ jsx("span", { style: { marginLeft: "auto", minWidth: 1 } }) }),
    /* @__PURE__ */ jsx(TidalEditorFooterAction, { children: /* @__PURE__ */ jsx(SpeechToTextComponent, { api: speechToTextApi, disabled }) }),
    /* @__PURE__ */ jsx(TidalEditorFooterAction, { children: /* @__PURE__ */ jsx(Tooltip, { title: texts.footer.sendActionTooltip, children: /* @__PURE__ */ jsx(IconButton, { sx: sendButtonSx, onClick: handleSend, disabled: disableSendButton, children: /* @__PURE__ */ jsx(Send, {}) }) }) })
  ] });
}
const sendButtonSx = (t) => ({
  color: t.vars.palette.primary.contrastText,
  background: t.vars.palette.primary.main,
  "& > svg": {
    // scale will not change the size of the button
    scale: 0.85
  },
  "&:hover": {
    background: t.vars.palette.primary.dark,
    color: t.vars.palette.primary.contrastText
  }
});
export {
  EditorFooter
};
//# sourceMappingURL=EditorFooter.js.map
