import { useLexicalComposerContext } from "@lexical/react/LexicalComposerContext";
import { useEditorAPI } from "@workwave-tidal/core/components";
import { $getRoot, COMMAND_PRIORITY_HIGH, KEY_ENTER_COMMAND } from "lexical";
import { useCallback, useEffect, useRef } from "react";
import { useConversationOptions } from "../../../../ConversationOptionsProvider.js";
import { useScrollbarScrollToBottom } from "../../../../ScrollApiProvider.js";
function useSendAction(props) {
  const { onSend, speechToTextApi } = props;
  const { scrollToEndAfterMessageSend } = useConversationOptions();
  const scrollToBottom = useScrollbarScrollToBottom();
  const onSendRef = useRef(onSend);
  useEffect(() => {
    onSendRef.current = onSend;
  }, [onSend]);
  const api = useEditorAPI();
  const [editor] = useLexicalComposerContext();
  const handleSend = useCallback(() => {
    const text = api.toString();
    if (text.trim() === "") return;
    onSendRef.current?.(text);
    if (scrollToEndAfterMessageSend) {
      setTimeout(scrollToBottom, 0);
    }
    editor.update(() => {
      const root = $getRoot();
      root.clear();
    });
    if (speechToTextApi.current !== false) {
      speechToTextApi.current?.stopRecording();
    }
  }, [api, editor, scrollToEndAfterMessageSend, scrollToBottom, speechToTextApi]);
  useEffect(() => {
    const unregister = editor.registerCommand(
      KEY_ENTER_COMMAND,
      (event) => {
        if (event === null) return false;
        if (event.shiftKey) return true;
        event.preventDefault();
        event.stopPropagation();
        handleSend();
        return true;
      },
      COMMAND_PRIORITY_HIGH
    );
    return () => {
      unregister();
    };
  }, [editor, handleSend]);
  return handleSend;
}
export {
  useSendAction
};
//# sourceMappingURL=useSendAction.js.map
