import { jsx, jsxs } from "react/jsx-runtime";
import { Close as CloseIcon, SupportAgent as SupportAgentIcon } from "@mui/icons-material";
import { Box, Fab as MuiFab, Zoom, keyframes, useTheme } from "@mui/material";
function Fab(props) {
  const {
    sx,
    open,
    onClick,
    bounce,
    testId = "TidalConversationFab",
    className,
    fabAnimation = bounceAnimation,
    slots: { closeIcon = /* @__PURE__ */ jsx(CloseIcon, {}), openIcon = /* @__PURE__ */ jsx(SupportAgentIcon, {}) } = {},
    slotsProps: { fab } = {},
    disabled
  } = props;
  const theme = useTheme();
  const transitionDuration = {
    enter: theme.transitions.duration.enteringScreen * 0.6,
    exit: theme.transitions.duration.leavingScreen * 0.6
  };
  return /* @__PURE__ */ jsx(
    MuiFab,
    {
      color: "primary",
      ...fab,
      disabled,
      disableRipple: true,
      className,
      "data-testid": testId,
      sx: (t) => {
        const userSx = typeof sx === "function" ? sx(t) : Array.isArray(sx) ? sx[0] : sx;
        return {
          animation: bounce ? `${fabAnimation} 2.5s infinite` : void 0,
          ...userSx
        };
      },
      onClick,
      children: /* @__PURE__ */ jsxs(
        Box,
        {
          sx: {
            position: "relative",
            width: "100%",
            height: "100%",
            "& > *": {
              position: "absolute",
              top: "50%",
              left: "50%",
              translate: "-50% -50%"
            }
          },
          children: [
            /* @__PURE__ */ jsx(
              Zoom,
              {
                in: open,
                timeout: transitionDuration,
                style: {
                  transitionDelay: `${open ? transitionDuration.exit : 0}ms`
                },
                unmountOnExit: true,
                children: closeIcon
              }
            ),
            /* @__PURE__ */ jsx(
              Zoom,
              {
                in: !open,
                timeout: transitionDuration,
                style: {
                  transitionDelay: `${open ? 0 : transitionDuration.exit}ms`
                },
                unmountOnExit: true,
                children: openIcon
              }
            )
          ]
        }
      )
    }
  );
}
const bounceAnimation = keyframes`
  70% { translate: 0 0% }
  80% { translate: 0 -22% }
  90% { translate: 0 0% }
  95% { translate: 0 -12% }
  97% { translate: 0 0% }
  99% { translate: 0 -5% }
  100% { translate: 0 0 }
`;
export {
  Fab
};
//# sourceMappingURL=Fab.js.map
