import { jsx } from "react/jsx-runtime";
import { createContext, useContext, useMemo } from "react";
import { useReducer } from "react";
const feedbackFormState = createContext({
  notes: "",
  suggestions: {}
});
const feedbackFormApi = createContext({
  setNotes: () => {
  },
  setSuggestion: () => {
  }
});
function formReducer(state, action) {
  switch (action.type) {
    case "setNotes":
      return { ...state, notes: action.notes };
    case "setSuggestion":
      return { ...state, suggestions: { ...state.suggestions, [action.id]: action.value } };
    default:
      return state;
  }
}
function initializer(suggestions) {
  return {
    notes: "",
    suggestions: Object.fromEntries(suggestions.map((s) => [s.id, Boolean(s.initiallyChecked)]))
  };
}
function useCreateContext(suggestions) {
  const [state, dispatch] = useReducer(formReducer, suggestions, initializer);
  const api = useMemo(
    () => ({
      setNotes: (notes) => dispatch({ type: "setNotes", notes }),
      setSuggestion: (id, value) => dispatch({ type: "setSuggestion", id, value })
    }),
    []
  );
  return { api, state };
}
function FormProvider(props) {
  const { children, suggestions } = props;
  const { api, state } = useCreateContext(suggestions);
  return /* @__PURE__ */ jsx(feedbackFormApi.Provider, { value: api, children: /* @__PURE__ */ jsx(feedbackFormState.Provider, { value: state, children }) });
}
function useFormState() {
  return useContext(feedbackFormState);
}
function useFormApi() {
  return useContext(feedbackFormApi);
}
export {
  FormProvider,
  useFormApi,
  useFormState
};
//# sourceMappingURL=FormProvider.js.map
