import { useCallback, useEffect, useRef, useState } from "react";
import { useChatOpen, useFloatingConversationApi } from "../components/FloatingConversationApiProvider.js";
function useFabProps(props) {
  const [fabRef, setFabRef] = useState(() => null);
  const { setFullScreen, setChatOpen } = useFloatingConversationApi();
  const chatOpen = useChatOpen();
  const rApi = useRef({ setFullScreen, setChatOpen });
  useEffect(() => {
    rApi.current.setFullScreen = setFullScreen;
    rApi.current.setChatOpen = setChatOpen;
  }, [setFullScreen, setChatOpen]);
  const initialOpenState = useRef(props?.slotProps?.fab?.open ?? false);
  useEffect(() => {
    rApi.current.setChatOpen(initialOpenState.current);
  }, []);
  const userControlledBounceState = typeof props?.slotProps?.fab?.open === "boolean";
  const userControlledBounce = props?.slotProps?.fab?.bounce ?? false;
  const rCallbacks = useRef({
    onClick: props?.slotProps?.fab?.onClick,
    onDragStart: props?.slotProps?.fab?.onDragStart
  });
  useEffect(() => {
    rCallbacks.current.onClick = props?.slotProps?.fab?.onClick;
    rCallbacks.current.onDragStart = props?.slotProps?.fab?.onDragStart;
  }, [props?.slotProps?.fab?.onClick, props?.slotProps?.fab?.onDragStart]);
  const handleClick = useCallback(() => {
    rApi.current.setChatOpen((prev) => !prev);
    rCallbacks.current.onClick?.();
  }, []);
  const handleOnDragStart = useCallback(() => {
    rApi.current.setFullScreen(false);
    rCallbacks.current.onDragStart?.();
  }, []);
  const fabProps = {
    ...props?.slotProps?.fab,
    open: chatOpen,
    // if the user doesn't control the `bounce` state, it will bounce only when the conversation is closed
    bounce: userControlledBounceState ? userControlledBounce : !chatOpen,
    onClick: handleClick,
    onDragStart: handleOnDragStart
  };
  return {
    fabProps,
    setFabRef,
    fabRef
  };
}
export {
  useFabProps
};
//# sourceMappingURL=useFabProps.js.map
