import { useTheme } from "@mui/material";
import { useMemo } from "react";
import { useChatOpen } from "../components/FloatingConversationApiProvider.js";
function usePopperProps(props, $root) {
  const open = useChatOpen();
  const {
    slotProps: { popper } = {}
  } = props;
  const theme = useTheme();
  const popperProps = useMemo(() => {
    const popperSx = typeof popper?.sx === "function" ? popper.sx(theme) : popper?.sx;
    return {
      open,
      keepMounted: true,
      placement: "top-end",
      anchorEl: $root !== null ? $root : virtualElement,
      disablePortal: true,
      popperOptions: {
        ...popper?.popperOptions,
        modifiers: [
          {
            name: "offset",
            options: {
              offset: [0, 8]
            }
          }
        ]
      },
      sx: {
        ...popperSx,
        zIndex: theme.zIndex.modal
      },
      ...popper
    };
  }, [$root, open, popper, theme]);
  return popperProps;
}
function generateGetBoundingClientRect(x = 0, y = 0) {
  return () => ({
    width: 0,
    height: 0,
    top: y,
    right: x,
    bottom: y,
    left: x
  });
}
const virtualElement = {
  getBoundingClientRect: generateGetBoundingClientRect()
};
export {
  usePopperProps
};
//# sourceMappingURL=usePopperProps.js.map
