import { jsx, jsxs } from "react/jsx-runtime";
import { ArrowDownward } from "@mui/icons-material";
import { Children, useCallback, useEffect, useRef, useState } from "react";
import { useConversationOptions } from "../ConversationOptionsProvider.js";
import { useScrollbarConfigureApi } from "../ScrollApiProvider.js";
import { ConversationsRoot } from "./components/ConversationsRoot.js";
import { Root } from "./components/Root.js";
import { ScrollToBottom } from "./components/ScrollToBottom.js";
import { ScrollableArea } from "./components/ScrollableArea.js";
function ConversationInteractions(props) {
  const { testId, children, conversationEmpty } = props;
  const { handleScrollToBottom, scrollbarVisible, showFab, scrollIsAtBottom, scrollerRef } = useReactToScroll();
  useReadFlow(scrollIsAtBottom, handleScrollToBottom, children);
  if (Children.count(children) === 0) return conversationEmpty ?? null;
  return /* @__PURE__ */ jsxs(ConversationsRoot, { children: [
    /* @__PURE__ */ jsx(ScrollableArea, { ref: scrollerRef, children: /* @__PURE__ */ jsx(Root, { "data-testid": testId, "data-tidal": "ConversationInteractions", sx: { pr: scrollbarVisible ? 1 : 2 }, children }) }),
    showFab ? /* @__PURE__ */ jsx(ScrollToBottom, { onScrollToBottom: handleScrollToBottom, children: /* @__PURE__ */ jsx(ArrowDownward, {}) }) : null
  ] });
}
function useReactToScroll() {
  const scrollerRef = useRef(null);
  const [showFab, setShowFab] = useState(false);
  const scrollIsAtBottom = useRef(false);
  const autoScrollToBottomDone = useRef(false);
  const { preventScrollToBottomOnMount, scrollThresholdBeforeShowScrollToBottom, hideScrollToBottomFab } = useConversationOptions();
  const { registerScrollToBottom } = useScrollbarConfigureApi();
  const scrollbarVisible = scrollerRef.current ? scrollerRef.current.scrollHeight > scrollerRef.current.clientHeight : false;
  const handleScrollToBottom = useCallback(() => {
    if (!scrollerRef.current) return;
    scrollerRef.current.scrollTo({ top: scrollerRef.current.scrollHeight ?? 0 });
  }, []);
  useEffect(() => {
    const scroller = scrollerRef.current;
    if (!scroller) return;
    const controller = new AbortController();
    const observer = new ResizeObserver((_) => {
      const scrollQty = scroller.scrollTop + scroller.clientHeight;
      scrollIsAtBottom.current = scrollQty >= scroller.scrollHeight;
      setShowFab(scrollQty + scrollThresholdBeforeShowScrollToBottom <= scroller.scrollHeight);
    });
    observer.observe(scroller);
    scroller.addEventListener(
      "scroll",
      () => {
        const scrollQty = scroller.scrollTop + scroller.clientHeight;
        scrollIsAtBottom.current = scrollQty >= scroller.scrollHeight;
        setShowFab(scrollQty + scrollThresholdBeforeShowScrollToBottom <= scroller.scrollHeight);
      },
      { signal: controller.signal }
    );
    return () => {
      controller.abort();
      observer.disconnect();
    };
  }, [scrollThresholdBeforeShowScrollToBottom]);
  useEffect(() => {
    const scroller = scrollerRef.current;
    if (!scroller) return;
    if (preventScrollToBottomOnMount) return;
    if (autoScrollToBottomDone.current) return;
    autoScrollToBottomDone.current = true;
    requestAnimationFrame(() => {
      scroller.scrollTo({ top: scroller.scrollHeight ?? 0 });
    });
  }, [preventScrollToBottomOnMount]);
  useEffect(() => {
    registerScrollToBottom(handleScrollToBottom);
  }, [registerScrollToBottom, handleScrollToBottom]);
  return {
    showFab: hideScrollToBottomFab ? false : showFab,
    scrollbarVisible,
    handleScrollToBottom,
    scrollIsAtBottom,
    scrollerRef
  };
}
function useReadFlow(scrollIsAtBottom, handleScrollToBottom, interactionElements) {
  const { disableAutoReadFlow } = useConversationOptions();
  useEffect(() => {
    if (disableAutoReadFlow) return;
    if (scrollIsAtBottom.current) {
      handleScrollToBottom();
    }
    interactionElements;
  }, [
    disableAutoReadFlow,
    interactionElements,
    handleScrollToBottom,
    // this is a mutable ref, but biome is not able to recognize it, adding it as a dependency is harmless
    scrollIsAtBottom
  ]);
}
export {
  ConversationInteractions
};
//# sourceMappingURL=ConversationInteractions.js.map
