import { jsx, jsxs } from "react/jsx-runtime";
import { ThumbDown, ThumbDownOffAlt, ThumbUp, ThumbUpOffAlt } from "@mui/icons-material";
import { IconButton, Stack, Tooltip, buttonClasses } from "@mui/material";
import { isDev } from "@workwave-tidal/core/base";
import { useRef } from "react";
import { useConversationApi } from "../../ConversationApiProvider.js";
import { useConversationTexts } from "../../LocaleProvider.js";
import { InteractionCustomSlot } from "../components/Interaction/components/InteractionCustomSlot.js";
import { useInteractionId } from "../components/Interaction/components/InteractionIdProvider.js";
const buttonSx = {
  color: (t) => t.vars.palette.action.active,
  [`&.${buttonClasses.disabled}`]: {
    color: (t) => t.vars.palette.action.active
  }
};
function Rating(props) {
  const { onChange, reaction } = props;
  const {
    rating: { likeTooltip, dislikeTooltip }
  } = useConversationTexts();
  const id = useInteractionId();
  const conversationApi = useConversationApi();
  const reactionUnderSubmission = useRef(false);
  const reactionCommitted = Boolean(reaction);
  async function handleLike() {
    if (reactionUnderSubmission.current || reactionCommitted) return;
    reactionUnderSubmission.current = true;
    try {
      await onChange(id, "like", conversationApi);
    } catch (e) {
      if (isDev()) {
        console.log("Error while submitting reaction");
        console.log(e);
      }
      throw e;
    } finally {
      reactionUnderSubmission.current = false;
    }
  }
  async function handleDisLike() {
    if (reactionUnderSubmission.current || reactionCommitted) return;
    reactionUnderSubmission.current = true;
    try {
      await onChange(id, "dislike", conversationApi);
    } catch (e) {
      if (isDev()) {
        console.log("Error while submitting reaction");
        console.log(e);
      }
      throw e;
    } finally {
      reactionUnderSubmission.current = false;
    }
  }
  return /* @__PURE__ */ jsx(InteractionCustomSlot, { placement: "outside-border", children: /* @__PURE__ */ jsxs(Stack, { direction: "row", spacing: 0.5, children: [
    /* @__PURE__ */ jsx(Tooltip, { title: likeTooltip, children: /* @__PURE__ */ jsx(IconButton, { disabled: reactionCommitted, size: "small", onClick: handleLike, sx: buttonSx, children: reaction === "like" ? /* @__PURE__ */ jsx(ThumbUp, {}) : /* @__PURE__ */ jsx(ThumbUpOffAlt, {}) }) }),
    /* @__PURE__ */ jsx(Tooltip, { title: dislikeTooltip, children: /* @__PURE__ */ jsx(IconButton, { disabled: reactionCommitted, size: "small", onClick: handleDisLike, sx: buttonSx, children: reaction === "dislike" ? /* @__PURE__ */ jsx(ThumbDown, {}) : /* @__PURE__ */ jsx(ThumbDownOffAlt, {}) }) })
  ] }) });
}
export {
  Rating
};
//# sourceMappingURL=Rating.js.map
