import { jsx, jsxs } from "react/jsx-runtime";
import { Stack } from "@mui/material";
import { WormholeChildren, useWormhole } from "@workwave-tidal/core/hooks";
import { generateInteractionWormholeId } from "../../worms.js";
import { Avatar } from "./components/Avatar.js";
import { InteractionHeader } from "./components/InteractionHeader.js";
import { InteractionIdProvider } from "./components/InteractionIdProvider.js";
import { InteractionLoading } from "./components/InteractionLoading.js";
import { InteractionRoot } from "./components/InteractionRoot.js";
import { MessageTypography } from "./components/MessageTypography.js";
import { SenderTypography } from "./components/SenderTypography.js";
import { TimeTypography } from "./components/TimeTypography.js";
function ConversationInteraction(props) {
  return /* @__PURE__ */ jsx(InteractionIdProvider, { id: props.id, children: /* @__PURE__ */ jsx(ConversationInteractionInner, { ...props }) });
}
function ConversationInteractionInner(props) {
  const {
    // -----------------------------------
    // functional props
    id,
    time,
    sender,
    avatar,
    message,
    // -----------------------------------
    // visual states
    loading,
    loadingComponent = /* @__PURE__ */ jsx(InteractionLoading, { ml: 2, mt: 2 }),
    // -----------------------------------
    // visual props
    sx,
    variant = "default",
    children,
    alignment = "left",
    className = "",
    contentType = "text",
    slotProps: {
      root: rootProps,
      avatar: avatarProps,
      interactionHeader: interactionHeaderProps,
      senderTypography: senderTypographyProps,
      timeTypography: timeTypographyProps,
      messageTypography: messageTypographyProps
    } = {}
  } = props;
  const ownerState = { alignment, variant };
  const showHeader = sender || time;
  const { worms: belowMessage } = useWormhole(generateInteractionWormholeId(id, "below-message"));
  const { worms: outsideBorder } = useWormhole(generateInteractionWormholeId(id, "outside-border"));
  return /* @__PURE__ */ jsxs(Stack, { gap: 0.5, "data-interaction-id": id, "data-tidal": "ConversationInteraction", children: [
    /* @__PURE__ */ jsx(WormholeChildren, { children }),
    /* @__PURE__ */ jsxs(InteractionRoot, { ownerState, ...rootProps, className, sx, children: [
      avatar ? /* @__PURE__ */ jsx(Avatar, { ...avatarProps, children: avatar }) : null,
      /* @__PURE__ */ jsxs(Stack, { gap: 0.25, children: [
        showHeader ? /* @__PURE__ */ jsxs(InteractionHeader, { ownerState, ...interactionHeaderProps, children: [
          sender ? /* @__PURE__ */ jsx(SenderTypography, { ...senderTypographyProps, children: sender }) : null,
          time ? /* @__PURE__ */ jsx(TimeTypography, { ...timeTypographyProps, children: time }) : null
        ] }) : null,
        message ? contentType === "html" ? message : /* @__PURE__ */ jsx(MessageTypography, { ...messageTypographyProps, children: message }) : null,
        belowMessage,
        loading ? loadingComponent : null
      ] })
    ] }),
    outsideBorder
  ] });
}
export {
  ConversationInteraction
};
//# sourceMappingURL=ConversationInteraction.js.map
