import { useEffect, useRef, useState } from "react";
function useSpeechToText(props) {
  const { onChange, onEnd, onError, onStart } = props;
  const [recording, setRecording] = useState(false);
  const recognitionRef = useRef(null);
  const allowRecording = useRef(Boolean(window.SpeechRecognition || window.webkitSpeechRecognition));
  const onChangeRef = useRef(onChange);
  useEffect(() => {
    onChangeRef.current = onChange;
  }, [onChange]);
  const onErrorRef = useRef(onError);
  useEffect(() => {
    onErrorRef.current = onError;
  }, [onError]);
  useEffect(() => {
    if (!allowRecording.current) return;
    const recognition = new (window.SpeechRecognition || window.webkitSpeechRecognition)();
    recognitionRef.current = recognition;
    recognition.continuous = true;
    recognition.interimResults = true;
    recognition.onstart = () => setRecording(true);
    recognition.onresult = (event) => {
      let resultText = "";
      let finalText = "";
      for (let i = event.resultIndex; i < event.results.length; i++) {
        if (event.results[i].isFinal) {
          finalText += event.results[i][0].transcript;
        }
        resultText += event.results[i][0].transcript;
      }
      onChangeRef.current?.(resultText, "interim");
      if (finalText) {
        onChangeRef.current?.(finalText, "final");
      }
    };
    recognition.onerror = (event) => {
      onErrorRef.current?.(event);
      setRecording(false);
    };
    recognition.onend = () => setRecording(false);
    return () => {
      recognition.stop();
      recognition.abort();
      recognitionRef.current = null;
    };
  }, []);
  const startRecording = () => {
    recognitionRef.current?.start();
    onStart?.();
  };
  const stopRecording = () => {
    recognitionRef.current?.stop();
    onEnd?.();
  };
  const toggleRecording = () => {
    if (recording) {
      stopRecording();
    } else {
      startRecording();
    }
  };
  if (!allowRecording.current) return false;
  return {
    recording,
    toggleRecording,
    stopRecording,
    startRecording
  };
}
export {
  useSpeechToText
};
//# sourceMappingURL=useSpeechToText.js.map
