import { jsx, jsxs } from "react/jsx-runtime";
import {
  GridToolbarColumnsButton,
  GridToolbarContainer,
  GridToolbarDensitySelector,
  GridToolbarExport,
  GridToolbarFilterButton
} from "@mui/x-data-grid-pro";
import { useWormhole } from "@workwave-tidal/core/hooks";
import { DataGridToolbarRoot } from "./components/DataGridToolbarRoot.js";
import { GridToolbarQuickFilter } from "./components/GridToolbarQuickFilter.js";
import { LoadingIndicator } from "./components/LoadingIndicator.js";
import { LoadingProvider, useLoading } from "./components/LoadingProvider.js";
import { LocaleProvider } from "./components/LocaleProvider.js";
import { SelectedRowsCount } from "./components/SelectedRowsCount.js";
import { SelectionControl } from "./components/SelectionControl.js";
import { UserActionControlsRoot } from "./components/UserActionControlsRoot.js";
import { useWormholeId } from "./components/WormholeIdProvider.js";
import { useRowSelection } from "./hooks/useRowSelection.js";
function DataGridToolbar(props) {
  return /* @__PURE__ */ jsx(LocaleProvider, { localeText: props.localeText, children: /* @__PURE__ */ jsx(LoadingProvider, { children: /* @__PURE__ */ jsx(_DataGridToolbar, { ...props }) }) });
}
function _DataGridToolbar(props) {
  const {
    showQuickFilter,
    exportProps,
    quickFilterProps,
    sx,
    className,
    testId,
    disableSelectAll = false,
    noSelectionContent
  } = props;
  const { noSelectedRows } = useRowSelection();
  const { worms: insideToolbarContainer } = useWormhole(useWormholeId("insideToolbarContainer"));
  const { worms: actions } = useWormhole(useWormholeId("actions"));
  const loading = useLoading();
  return /* @__PURE__ */ jsxs(DataGridToolbarRoot, { "data-tidal": "DataGridToolbar", children: [
    /* @__PURE__ */ jsxs(GridToolbarContainer, { sx, className, "data-testid": testId, children: [
      /* @__PURE__ */ jsx(GridToolbarColumnsButton, {}),
      /* @__PURE__ */ jsx(GridToolbarFilterButton, {}),
      /* @__PURE__ */ jsx(GridToolbarDensitySelector, {}),
      /* @__PURE__ */ jsx(GridToolbarExport, { ...exportProps }),
      insideToolbarContainer,
      /* @__PURE__ */ jsx("div", { style: { flex: 1 } }),
      showQuickFilter && /* @__PURE__ */ jsx(GridToolbarQuickFilter, { ...quickFilterProps })
    ] }),
    noSelectedRows && noSelectionContent !== void 0 ? noSelectionContent : /* @__PURE__ */ jsxs(UserActionControlsRoot, { children: [
      /* @__PURE__ */ jsx(SelectedRowsCount, {}),
      /* @__PURE__ */ jsx(SelectionControl, { disableSelectAll }),
      actions
    ] }),
    /* @__PURE__ */ jsx(LoadingIndicator, { loading })
  ] });
}
export {
  DataGridToolbar
};
//# sourceMappingURL=DataGridToolbar.js.map
