import { jsx, jsxs } from "react/jsx-runtime";
import { Wormhole } from "@workwave-tidal/core/hooks";
import { Children, cloneElement, isValidElement } from "react";
import { isDev } from "@workwave-tidal/core/base";
import { useWormholeId } from "../WormholeIdProvider.js";
import { BulkAction } from "./BulkAction.js";
import { BulkActionsMenu } from "./BulkActionsMenu.js";
import { MenuStateProvider } from "./MenuStateProvider.js";
function _BulkActions(props) {
  const { maxVisibleActions = 1, children: actions } = props;
  if (!actions) return null;
  const childrenCount = Children.count(actions);
  if (childrenCount === 0) return null;
  const validActions = Children.toArray(actions).filter(
    (action) => isValidAction(action)
  );
  const validActionsCount = Children.count(validActions);
  if (validActionsCount !== childrenCount && isDev()) {
    console.warn("BulkActions: Only BulkAction components are allowed as children");
  }
  const _mode = validActionsCount <= maxVisibleActions ? "button" : "menuItem";
  const children = Children.map(validActions, (action) => {
    return cloneElement(action, { ...action.props, _mode });
  });
  return /* @__PURE__ */ jsxs(MenuStateProvider, { children: [
    _mode === "button" && children,
    _mode === "menuItem" && /* @__PURE__ */ jsx(BulkActionsMenu, { children })
  ] });
}
function BulkActions(props) {
  const target = useWormholeId("actions");
  return /* @__PURE__ */ jsx(Wormhole, { target, children: /* @__PURE__ */ jsx(_BulkActions, { ...props }) });
}
function isValidAction(action) {
  if (!isValidElement(action)) return false;
  return action.type === BulkAction;
}
export {
  BulkActions
};
//# sourceMappingURL=BulkActions.js.map
