import { jsx, jsxs } from "react/jsx-runtime";
import { Box, LinearProgress, keyframes, linearProgressClasses, styled, useTheme } from "@mui/material";
import { useMemo } from "react";
const loadAnimation = keyframes`
  from {
    left: var(--startPosition);
  }
  65% {
    left: 100%;
  }
  100% {
    left: var(--startPosition);
  }
`;
const SuperCar = styled("div", {
  slot: "SuperCar"
})`
  animation: ${loadAnimation} infinite var(--duration, 3s);
  background: var(--color);
  position: absolute;
  width: var(--size);
  z-index: 10;
  height: 100%;
  left: 0;
  top: 0;
`;
function useStyles(props) {
  const { size, duration, color } = props;
  return useMemo(() => {
    return {
      root: {
        "--duration": duration ? `${duration}s` : void 0,
        "--startPosition": `-${size}px`,
        "--color": color,
        "--size": `${size}px`
      }
    };
  }, [color, duration, size]);
}
function LoadingIndicator(props) {
  const { size = 120, duration, loading } = props;
  const theme = useTheme();
  const styles = useStyles({
    size,
    duration,
    color: theme.palette.primary.main
  });
  return /* @__PURE__ */ jsxs(Root, { children: [
    /* @__PURE__ */ jsx(
      LinearProgress,
      {
        variant: "determinate",
        value: 0,
        sx: (theme2) => ({
          height: 2,
          [`&.${linearProgressClasses.colorPrimary}`]: {
            backgroundColor: loading ? void 0 : theme2.vars.palette.divider
          }
        })
      }
    ),
    loading && /* @__PURE__ */ jsx(SuperCar, { style: styles.root })
  ] });
}
const Root = styled(Box, {
  slot: "Root"
})(() => ({
  position: "absolute",
  bottom: 0,
  left: 0,
  width: "100%",
  "& > *": {
    position: "absolute",
    width: "100%",
    left: 0,
    top: 0
  }
}));
export {
  LoadingIndicator
};
//# sourceMappingURL=LoadingIndicator.js.map
