import { jsx } from "react/jsx-runtime";
import { createContext, useContext, useMemo } from "react";
const formatEnglishNumber = new Intl.NumberFormat("en-US").format;
const defaultLocaleText = {
  selectedRows: (params) => `${formatEnglishNumber(params.selectedRowsCount)} ${params.selectedRowsCount < 2 ? "row" : "rows"} selected`,
  selectAll: (params) => `Select all ${formatEnglishNumber(params.totalRowsCount)} rows `,
  deselectAll: (_) => `Clear selection`,
  menuButton: "Actions"
};
const localeContext = createContext(defaultLocaleText);
function LocaleProvider(props) {
  const { children, localeText } = props;
  const contextValue = useMemo(
    () => ({
      ...defaultLocaleText,
      ...localeText
    }),
    [localeText]
  );
  return /* @__PURE__ */ jsx(localeContext.Provider, { value: contextValue, children });
}
function useLocale() {
  return useContext(localeContext);
}
export {
  LocaleProvider,
  defaultLocaleText,
  localeContext,
  useLocale
};
//# sourceMappingURL=LocaleProvider.js.map
