import { useGridApiContext } from "@mui/x-data-grid-pro";
import { useEffect, useState } from "react";
function useRowSelection() {
  const apiRef = useGridApiContext();
  const [selectedRows, setSelectedRows] = useState(() => {
    if (apiRef.current) {
      return Array.from(apiRef.current.getSelectedRows().keys());
    }
    return [];
  });
  const [totalRowsCount, setTotalRows] = useState(() => apiRef.current?.getRowsCount() ?? 0);
  useEffect(() => {
    const unsubscribeSelectionChange = apiRef.current.subscribeEvent("rowSelectionChange", (params) => {
      setSelectedRows([...params]);
    });
    const unsubscribeStateChange = apiRef.current.subscribeEvent("stateChange", (params) => {
      setTotalRows(params.rows.totalRowCount);
    });
    return () => {
      unsubscribeSelectionChange();
      unsubscribeStateChange();
    };
  }, [apiRef]);
  const selectionTextParams = {
    selectedRowsCount: selectedRows.length,
    totalRowsCount,
    gridApi: apiRef.current
  };
  return {
    selectionTextParams,
    selectedRows,
    totalRowsCount,
    allRowsSelected: selectedRows.length === totalRowsCount,
    noSelectedRows: selectedRows.length === 0
  };
}
export {
  useRowSelection
};
//# sourceMappingURL=useRowSelection.js.map
