import { jsx } from "react/jsx-runtime";
import { useTheme } from "@mui/material";
import { cloneElement, useCallback } from "react";
import { ActionBar as TidalActionBar } from "@workwave-tidal/core/components/ActionBar";
import { isDev } from "@workwave-tidal/core/base";
import { ActionBarPlacer } from "./ActionBarPlacer.js";
function ActionBarSmall(props) {
  const { actions, disabled } = props;
  const createFirstActionSx = useCreateFirstActionSx();
  if (!Array.isArray(actions)) return null;
  if (actions.length === 0) return null;
  if (actions.length > 1 && isDev()) {
    console.warn('Only 1 action is allowed when using size="small", the other actions will be ignored');
  }
  const firstAction = actions[0];
  const actionProps = {
    mode: "default",
    color: "default",
    divider: false,
    sx: createFirstActionSx(firstAction.props.sx)
  };
  if (typeof firstAction.props.onClick === "function") {
    actionProps.onClick = createOnClickWithStopPropagation(firstAction.props.onClick);
  }
  return /* @__PURE__ */ jsx(ActionBarPlacer, { size: "small", children: /* @__PURE__ */ jsx(TidalActionBar, { limit: 1, disabled, children: cloneElement(firstAction, {
    ...actionProps,
    key: firstAction.props.id
  }) }) });
}
function createOnClickWithStopPropagation(onClick) {
  return (event) => {
    event.stopPropagation();
    onClick?.(event);
  };
}
function useCreateFirstActionSx() {
  const theme = useTheme();
  return useCallback(
    (actionSx = {}) => {
      const baseSx = {
        padding: `1px`,
        background: theme.vars.palette.common.white,
        border: `1px solid ${theme.vars.palette.grey[300]}`,
        "&:hover": {
          background: theme.vars.palette.common.white
        }
      };
      if (typeof actionSx === "function") {
        return {
          ...actionSx(theme),
          ...baseSx
        };
      }
      return {
        ...actionSx,
        ...baseSx
      };
    },
    [theme]
  );
}
export {
  ActionBarSmall
};
//# sourceMappingURL=SmallActionBar.js.map
