import { Box, styled } from "@mui/material";
import { cssClasses } from "../../../cssClasses.js";
const excludedProps = ["actionsVisibility", "hasError", "disabled"];
const Root = styled(Box, {
  name: "StandardFilePreview",
  slot: "Root",
  shouldForwardProp: (prop) => !excludedProps.includes(prop.toString())
})(({ theme, actionsVisibility, hasError, disabled, onClick }) => {
  const { lobsterRed, slateBlueGray } = theme.vars.palette.tidalColors;
  return {
    position: "relative",
    display: "grid",
    gridTemplateColumns: "auto 1fr auto",
    height: 58,
    minWidth: 160,
    overflow: "hidden",
    gap: theme.spacing(1),
    padding: theme.spacing(1),
    borderRadius: theme.spacing(0.5),
    borderWidth: 1,
    borderStyle: "solid",
    borderColor: hasError ? lobsterRed[500] : slateBlueGray[100],
    color: theme.palette.action.active,
    textTransform: "none",
    cursor: typeof onClick === "function" && !disabled ? "pointer" : "auto",
    transition: "background 0.25s ease",
    "&:hover": {
      backgroundColor: theme.palette.action.hover,
      borderColor: hasError ? lobsterRed[500] : slateBlueGray[300]
    },
    "&:focus-within": {
      backgroundColor: theme.palette.action.focus,
      borderColor: hasError ? lobsterRed[500] : slateBlueGray[500]
    },
    ...disabled && {
      color: theme.palette.text.disabled,
      "& *": {
        color: theme.palette.text.disabled
      }
    },
    ...actionsVisibility === "onHoverOrFocus" && {
      [`& .${cssClasses.actionBarPlacer}`]: {
        opacity: 0,
        translate: "20% 0",
        transition: "opacity 0.2s ease, translate 0.3s ease"
      }
    },
    // this will make the hoverSubtitle component invisible
    [`& .${cssClasses.hoverSubtitle}`]: hoverSubtitleOffRules,
    [`& .${cssClasses.subtitle}`]: hoverSubtitleOnRules,
    // this will make hover effect to not work on touch interfaces
    "@media (pointer: coarse)": {
      [`& .${cssClasses.actionBarPlacer}`]: actionBarPlacerOnRules
    },
    [`&:hover .${cssClasses.actionBarPlacer}`]: actionBarPlacerOnRules,
    [`&:focus-within .${cssClasses.actionBarPlacer}`]: actionBarPlacerOnRules,
    [`&:hover .${cssClasses.hoverSubtitle}`]: hoverSubtitleOnRules,
    [`&:focus-within .${cssClasses.hoverSubtitle}`]: hoverSubtitleOnRules,
    [`&:hover .${cssClasses.subtitle}`]: hoverSubtitleOffRules,
    [`&:focus-within .${cssClasses.subtitle}`]: hoverSubtitleOffRules
  };
});
const actionBarPlacerOnRules = {
  opacity: 1,
  translate: "0 0",
  transition: "opacity 0.2s ease, translate 0.3s ease"
};
const hoverSubtitleOnRules = {
  display: "inline-block"
};
const hoverSubtitleOffRules = {
  display: "none"
};
export {
  Root
};
//# sourceMappingURL=Root.js.map
