import { jsx, jsxs } from "react/jsx-runtime";
import { Children, forwardRef } from "react";
import { MasonryItem } from "./MasonryItem.js";
import { MasonryRoot } from "./components/MasonryRoot.js";
import { useMasonryState } from "./hooks/useMasonryState.js";
import { findLayoutItem } from "./utils/findLayoutItem.js";
const Masonry = forwardRef(function Masonry2(props, ref) {
  const {
    activeDrag,
    children,
    columns,
    containerPadding,
    handleDrag,
    handleDragStart,
    handleDragStop,
    isBounded,
    isDraggable,
    layout,
    margin,
    maxRows,
    rowHeight,
    style,
    transformScale,
    width,
    wrapperRef
  } = useMasonryState(props);
  const createMasonryItem = (child) => {
    if (!child || !child.key) return;
    const layoutItem = findLayoutItem(layout, String(child.key));
    if (!layoutItem) return;
    const draggable = typeof layoutItem.isDraggable === "boolean" ? layoutItem.isDraggable : !layoutItem.isStatic && isDraggable;
    const bounded = draggable && isBounded && layoutItem.isBounded !== false;
    return /* @__PURE__ */ jsx(
      MasonryItem,
      {
        ...layoutItem,
        columns,
        containerPadding,
        containerWidth: width,
        isBounded: bounded,
        isDraggable: draggable,
        margin,
        maxRows,
        onDrag: handleDrag,
        onDragStart: handleDragStart,
        onDragStop: handleDragStop,
        rowHeight,
        transformScale,
        children: child
      }
    );
  };
  return /* @__PURE__ */ jsx(MasonryRoot, { ref: wrapperRef, "data-tidal": "MasonryAutoSizeWrapper", children: /* @__PURE__ */ jsxs("div", { className: "react-grid-layout", ref, style, children: [
    Children.map(children, (child) => createMasonryItem(child)),
    activeDrag && /* @__PURE__ */ jsx(
      MasonryItem,
      {
        width: activeDrag.width,
        height: activeDrag.height,
        x: activeDrag.x,
        y: activeDrag.y,
        id: activeDrag.id,
        className: `react-grid-placeholder`,
        containerWidth: width,
        columns,
        margin,
        containerPadding: containerPadding || margin,
        maxRows,
        rowHeight,
        isDraggable: false,
        isBounded: false,
        transformScale,
        children: /* @__PURE__ */ jsx("div", {})
      }
    )
  ] }) });
});
export {
  Masonry
};
//# sourceMappingURL=Masonry.js.map
