import { useElementSize } from "@workwave-tidal/core/hooks";
import { useCallback, useEffect, useMemo, useRef, useState } from "react";
import { compact } from "../utils/compact.js";
import { findLayoutItem } from "../utils/findLayoutItem.js";
import { getDefaultMasonryProps } from "../utils/getDefaultMasonryProps.js";
import { getLayoutBottom } from "../utils/getLayoutBottom.js";
import { moveElement } from "../utils/moveElement.js";
import { synchronizeLayoutWithChildren } from "../utils/synchronizeLayoutWithChildren.js";
function useMasonryState(inProps) {
  const { width: initialWidth } = inProps;
  const props = getDefaultMasonryProps(inProps);
  const {
    allowOverlap,
    autoHeight,
    children,
    columns,
    compactType,
    containerPadding,
    initialLayout,
    margin,
    preventCollision,
    rowHeight,
    style: inStyle
  } = props;
  const rWrapper = useRef(null);
  const { width: wrapperWidth = 0 } = useElementSize(rWrapper.current);
  const [oldLayout, setOldLayout] = useState();
  const [activeDrag, setActiveDrag] = useState();
  const [layout, setLayout] = useState(
    initialLayout ? synchronizeLayoutWithChildren(initialLayout, children, columns, compactType, allowOverlap) : []
  );
  const [oldDragItem, setOldDragItem] = useState();
  const style = useMemo(() => {
    const bottom = getLayoutBottom(layout);
    const paddingY = containerPadding[1];
    const marginY = margin[1];
    const height = `${bottom * rowHeight + (bottom - 1) * marginY + paddingY * 2}px`;
    return {
      ...inStyle,
      height: autoHeight ? height : void 0
    };
  }, [layout, containerPadding, margin, rowHeight, autoHeight, inStyle]);
  useEffect(() => {
    setLayout(synchronizeLayoutWithChildren(initialLayout, children, columns, compactType, allowOverlap));
  }, [initialLayout, children, columns, compactType, allowOverlap]);
  const handleDragStart = useCallback(
    (id, x, y) => {
      const layoutItem = findLayoutItem(layout, id);
      if (!layoutItem) return;
      const placeholder = {
        id,
        width: layoutItem.width,
        height: layoutItem.height,
        x: layoutItem.x,
        y: layoutItem.y,
        placeholder: true
      };
      setOldDragItem(layoutItem);
      setOldLayout(layout);
      setActiveDrag(placeholder);
    },
    [layout]
  );
  const handleDrag = useCallback(
    (id, x, y) => {
      const layoutItem = findLayoutItem(layout, id);
      if (!layoutItem) return;
      const placeholder = {
        id,
        width: layoutItem.width,
        height: layoutItem.height,
        x: layoutItem.x,
        y: layoutItem.y,
        placeholder: true
      };
      const isUserAction = true;
      const nextLayout = moveElement(
        layout,
        layoutItem,
        compactType,
        columns,
        x,
        y,
        isUserAction,
        preventCollision,
        allowOverlap
      );
      setLayout(allowOverlap ? nextLayout : compact(nextLayout, compactType, columns));
      setActiveDrag(placeholder);
    },
    [layout, compactType, columns, preventCollision, allowOverlap]
  );
  const handleDragStop = useCallback(
    (id, x, y) => {
      if (!activeDrag) return;
      const layoutItem = findLayoutItem(layout, id);
      if (!layoutItem) return;
      const isUserAction = true;
      const nextLayout = moveElement(
        layout,
        layoutItem,
        compactType,
        columns,
        x,
        y,
        isUserAction,
        preventCollision,
        allowOverlap
      );
      setActiveDrag(void 0);
      setOldDragItem(void 0);
      setOldLayout(void 0);
      setLayout(allowOverlap ? nextLayout : compact(nextLayout, compactType, columns));
    },
    [layout, activeDrag, compactType, columns, preventCollision, allowOverlap]
  );
  return {
    ...props,
    activeDrag,
    handleDrag,
    handleDragStart,
    handleDragStop,
    layout,
    oldDragItem,
    oldLayout,
    style,
    width: initialWidth ?? wrapperWidth,
    wrapperRef: rWrapper
  };
}
export {
  useMasonryState
};
//# sourceMappingURL=useMasonryState.js.map
