import { getAllCollisions } from "./getAllCollisions.js";
import { getFirstLayoutItemCollision } from "./getFirstLayoutItemCollision.js";
import { sortLayout } from "./sortLayout.js";
function moveElementAwayFromCollision(layout, collidesWith, itemToMove, compactType, columns, initialIsUserAction) {
  let isUserAction = initialIsUserAction;
  const compactHorizontal = compactType === "horizontal";
  const compactVertical = compactType === "vertical";
  const preventCollision = collidesWith.isStatic;
  if (isUserAction) {
    isUserAction = false;
    const fakeItem = {
      x: compactHorizontal ? Math.max(collidesWith.x - itemToMove.width, 0) : itemToMove.x,
      y: compactVertical ? Math.max(collidesWith.y - itemToMove.height, 0) : itemToMove.y,
      width: itemToMove.width,
      height: itemToMove.height,
      id: "-1"
    };
    const firstCollision = getFirstLayoutItemCollision(layout, fakeItem);
    const collisionNorth = firstCollision && firstCollision.y + firstCollision.height > collidesWith.y;
    const collisionWest = firstCollision && collidesWith.x + collidesWith.width > firstCollision.x;
    if (!firstCollision) {
      return moveElement(
        layout,
        itemToMove,
        compactType,
        columns,
        compactHorizontal ? fakeItem.x : void 0,
        compactVertical ? fakeItem.y : void 0,
        isUserAction,
        preventCollision
      );
    }
    if (collisionNorth && compactVertical) {
      return moveElement(
        layout,
        itemToMove,
        compactType,
        columns,
        void 0,
        collidesWith.y + 1,
        isUserAction,
        preventCollision
      );
    }
    if (collisionNorth && compactType == null) {
      collidesWith.y = itemToMove.y;
      itemToMove.y = itemToMove.y + itemToMove.height;
      return layout;
    }
    if (collisionWest && compactHorizontal) {
      return moveElement(
        layout,
        collidesWith,
        compactType,
        columns,
        itemToMove.x,
        void 0,
        isUserAction,
        preventCollision
      );
    }
  }
  const nextX = compactHorizontal ? itemToMove.x + 1 : void 0;
  const nextY = compactVertical ? itemToMove.y + 1 : void 0;
  if (nextX == null && nextY == null) {
    return layout;
  }
  return moveElement(
    layout,
    itemToMove,
    compactType,
    columns,
    compactHorizontal ? itemToMove.x + 1 : void 0,
    compactVertical ? itemToMove.y + 1 : void 0,
    isUserAction,
    preventCollision
  );
}
function moveElement(layout, layoutItem, compactType, columns, x, y, isUserAction, preventCollision, allowOverlap) {
  if (layoutItem.isStatic && layoutItem.isDraggable !== true) return layout;
  if (layoutItem.y === y && layoutItem.x === x) return layout;
  let nextLayout = [...layout];
  const isVerticalShift = compactType === "vertical" && typeof y === "number";
  const isHorizontalShift = compactType === "horizontal" && typeof x === "number";
  const prevX = layoutItem.x;
  const prevY = layoutItem.y;
  if (typeof x === "number") layoutItem.x = x;
  if (typeof y === "number") layoutItem.y = y;
  layoutItem.moved = true;
  const sorted = sortLayout(layout, compactType);
  const isMovingUp = isVerticalShift ? prevY >= y : isHorizontalShift ? prevX >= x : false;
  if (isMovingUp) sorted.reverse();
  const collisions = getAllCollisions(sorted, layoutItem);
  const hasCollisions = collisions.length > 0;
  if (hasCollisions && allowOverlap) {
    layoutItem.moved = false;
    return layout;
  }
  if (hasCollisions && preventCollision) {
    layoutItem.x = prevX;
    layoutItem.y = prevY;
    layoutItem.moved = false;
    return layout;
  }
  for (let i = 0; i < collisions.length; i++) {
    const collision = collisions[i];
    if (collision.moved) continue;
    const collidesWith = collision.isStatic ? collision : layoutItem;
    const itemToMove = collision.isStatic ? layoutItem : collision;
    nextLayout = moveElementAwayFromCollision(nextLayout, collidesWith, itemToMove, compactType, columns, isUserAction);
  }
  layoutItem.moved = false;
  return nextLayout;
}
export {
  moveElement
};
//# sourceMappingURL=moveElement.js.map
