import { jsx } from "react/jsx-runtime";
import { Drawer, drawerClasses } from "@mui/material";
import { useWarnOnce } from "../../useWarnOnce.js";
import { DEFAULT_RAIL_VIEW_ID } from "../constants.js";
import { useAnchor } from "../hooks/useAnchor.js";
import { useToolbar } from "../hooks/useToolbar.js";
import { ActiveViewProvider } from "./ActiveViewProvider.js";
const placeholderRect = new DOMRect(0, 0, 0, 0);
function DrawerView(props) {
  const {
    view,
    children,
    placement = "left",
    customPlacement,
    railId = DEFAULT_RAIL_VIEW_ID,
    drawerProps,
    onClose
  } = props;
  const { componentsProps: drawerComponentsProps, sx: drawerSx, ...drawerPropsRest } = drawerProps ?? {};
  const { isActive, setViews, views } = useToolbar();
  const warnOnce = useWarnOnce();
  const $rail = useAnchor(railId);
  const showView = isActive(view);
  if (showView && !$rail) {
    warnOnce("rail anchor not found");
  }
  const handleClose = (_, reason) => {
    if (typeof onClose === "function") {
      onClose(reason, views, setViews);
      return;
    }
    setViews();
  };
  const rect = $rail?.getBoundingClientRect() ?? placeholderRect;
  const cssProps = customPlacement ? customPlacement(rect, placement) : placement === "right" ? { right: rect?.width ?? 0 } : { left: rect?.right ?? 0 };
  return /* @__PURE__ */ jsx(ActiveViewProvider, { view, children: /* @__PURE__ */ jsx(
    Drawer,
    {
      open: showView,
      anchor: placement,
      componentsProps: {
        backdrop: {
          sx: { backgroundColor: "transparent" },
          ...drawerComponentsProps?.backdrop ?? {}
        },
        root: drawerComponentsProps?.root
      },
      onClose: handleClose,
      sx: (theme) => ({
        [`& .${drawerClasses.paper}`]: {
          ...cssProps
        },
        ...typeof drawerSx === "function" ? drawerSx(theme) : drawerSx ?? {}
      }),
      ...drawerPropsRest,
      children
    }
  ) });
}
export {
  DrawerView
};
//# sourceMappingURL=DrawerView.js.map
