import { jsx, jsxs } from "react/jsx-runtime";
import { Box, Collapse, useTheme } from "@mui/material";
import { useRef, useState } from "react";
import { useToolbar } from "../../hooks/useToolbar.js";
import { DEFAULT_RAIL_VIEW_ID } from "../../constants.js";
import { ToolbarRail } from "../ToolbarRail/ToolbarRail.js";
import { ExpandableRailContextProvider } from "./ExpandableRailContextProvider/ExpandableRailContextProvider.js";
import { Root } from "./components/Root.js";
import { RoundToggleButton } from "./components/RoundToggleButton.js";
function ExpandableRail(props) {
  const {
    children,
    mode,
    setMode,
    collapsedSize,
    expandedSize,
    disableRoundToggleButton,
    sx: stackPropsSx,
    placement = "left",
    ...stackProps
  } = props;
  const [railWidth, setRailWidth] = useState(() => expandedSize);
  const theme = useTheme();
  const { registerAnchor } = useToolbar();
  const rootRef = useRef(null);
  registerAnchor(DEFAULT_RAIL_VIEW_ID, rootRef.current);
  const localSx = {
    width: railWidth,
    height: "100%"
  };
  const sx = stackPropsSx === void 0 ? localSx : typeof stackPropsSx === "function" ? { ...stackPropsSx(theme), ...localSx } : { ...stackPropsSx, ...localSx };
  const backgroundColor = stackProps.backgroundColor ?? theme.palette.workwaveBlue;
  const color = stackProps.color ?? theme.palette.common.white;
  return /* @__PURE__ */ jsx(ExpandableRailContextProvider, { mode, setMode, placement, children: /* @__PURE__ */ jsxs(Root, { ref: rootRef, "data-id": "ToolbarRailExpandableRoot", children: [
    /* @__PURE__ */ jsx(Box, { height: "100%", display: "flex", overflow: "hidden", width: "100%", children: /* @__PURE__ */ jsx(
      Collapse,
      {
        orientation: "horizontal",
        in: mode === "expanded",
        collapsedSize,
        onEnter: () => setRailWidth(expandedSize),
        onExited: () => setRailWidth(collapsedSize),
        children: /* @__PURE__ */ jsx(
          ToolbarRail,
          {
            disableAutoRegisterAnchor: true,
            enableLastChildGroup: true,
            ...stackProps,
            sx,
            backgroundColor,
            color,
            children
          }
        )
      }
    ) }),
    !disableRoundToggleButton && /* @__PURE__ */ jsx(RoundToggleButton, { color, backgroundColor, placement })
  ] }) });
}
export {
  ExpandableRail
};
//# sourceMappingURL=ExpandableRail.js.map
