import { jsx, jsxs } from "react/jsx-runtime";
import { ChevronRight } from "@mui/icons-material";
import {
  Avatar,
  Box,
  ListItemAvatar,
  ListItemButton,
  ListItemIcon,
  ListItemText,
  Tooltip,
  styled,
  useTheme
} from "@mui/material";
import { useEffect, useRef } from "react";
import { useWarnOnce } from "../../useWarnOnce.js";
import { useToolbar } from "../hooks/useToolbar.js";
import { useToolbarRailExpandable } from "../hooks/useToolbarRailExpandable.js";
function ExpandableRailListItem(props) {
  const {
    avatar,
    icon,
    primary,
    rightAdornment = /* @__PURE__ */ jsx(ChevronRight, {}),
    onClick,
    listItemProps,
    listItemButtonProps,
    anchorId
  } = props;
  const { mode, placement } = useToolbarRailExpandable();
  const { registerAnchor } = useToolbar();
  const listItemRef = useRef(null);
  const warnOnce = useWarnOnce();
  useEffect(() => {
    if (!!avatar && !!icon) {
      warnOnce(
        `[ToolbarRailExpandableItem] You cannot defined both "avatar" and "icon". The "avatar" will take precedence.`
      );
    }
  }, [warnOnce, avatar, icon]);
  const defaultAvatarText = primary ? primary.toString().substring(0, 2) : "";
  const leftAdornment = avatar ? (
    // Avatar
    /* @__PURE__ */ jsx(ListItemAvatar, { children: avatar })
  ) : icon ? (
    // Icon
    /* @__PURE__ */ jsx(ListItemIcon, { children: /* @__PURE__ */ jsx(IconContainer, { children: icon }) })
  ) : (
    // Default Avatar
    /* @__PURE__ */ jsx(ListItemAvatar, { children: /* @__PURE__ */ jsx(Avatar, { children: defaultAvatarText }) })
  );
  const theme = useTheme();
  const listItemTextSx = typeof listItemProps?.sx === "function" ? listItemProps.sx(theme) : listItemProps?.sx;
  const tooltip = mode === "collapsed" ? primary : "";
  const listItemButtonSx = typeof listItemButtonProps?.sx === "function" ? listItemButtonProps.sx(theme) : listItemButtonProps?.sx;
  if (anchorId) {
    registerAnchor(anchorId, listItemRef.current);
  }
  return /* @__PURE__ */ jsxs(ListItemButton, { onClick, sx: { ...listItemButtonSx, flex: 0 }, ...listItemButtonProps, ref: listItemRef, children: [
    /* @__PURE__ */ jsx(Tooltip, { title: tooltip, placement: "right", arrow: true, children: leftAdornment }),
    /* @__PURE__ */ jsx(
      ListItemText,
      {
        primary,
        ...listItemProps,
        sx: {
          ...listItemTextSx,
          flexShrink: 1,
          transition: mode === "collapsed" ? "opacity 0.1s ease, visibility 0.1s ease 0.1s" : "opacity 0.1s ease, visibility 0s",
          opacity: mode === "expanded" ? 1 : 0.3,
          visibility: mode === "expanded" ? "visible" : "hidden"
        },
        primaryTypographyProps: { noWrap: true, ...listItemProps?.primaryTypographyProps },
        secondaryTypographyProps: { noWrap: true, ...listItemProps?.secondaryTypographyProps }
      }
    ),
    /* @__PURE__ */ jsx(RightAdornmentContainer, { children: rightAdornment })
  ] });
}
const IconContainer = styled(Box)(() => ({
  width: 40,
  height: 40,
  display: "flex",
  alignItems: "center",
  justifyContent: "center"
}));
const RightAdornmentContainer = styled(Box)(() => ({
  flexShrink: 0,
  flexGrow: 0,
  display: "inline-flex"
}));
export {
  ExpandableRailListItem
};
//# sourceMappingURL=ExpandableRailListItem.js.map
