import { jsx, jsxs } from "react/jsx-runtime";
import { Tooltip } from "@mui/material";
import { useRef } from "react";
import { useToolbar } from "../../hooks/useToolbar.js";
import { useToolbarRail } from "../ToolbarRail/hooks/useToolbarRail.js";
import { toolbarButtonClasses, toolbarButtonName } from "./classes.js";
import { Badge } from "./components/Badge.js";
import { Icon } from "./components/Icon.js";
import { Label } from "./components/Label.js";
import { Root } from "./components/Root.js";
import { useToolbarButton } from "./hooks/useToolbarButton.js";
function ToolbarButton(props) {
  const {
    className = "",
    hoverBulge = true,
    indicator,
    label,
    testId = `${toolbarButtonName}-root`,
    tooltip = label,
    tooltipPlacement = "right",
    value,
    anchorId,
    showLabel: forceShowLabel,
    selectedIcon,
    ...rest
  } = props;
  const rootRef = useRef(null);
  const { icon, onClick, selected } = useToolbarButton(props);
  const { registerAnchor } = useToolbar();
  const { showLabels } = useToolbarRail();
  const showLabel = typeof forceShowLabel === "boolean" ? forceShowLabel : showLabels;
  if (anchorId) {
    registerAnchor(anchorId, rootRef.current);
  }
  return /* @__PURE__ */ jsx(Tooltip, { title: tooltip, placement: tooltipPlacement, children: /* @__PURE__ */ jsx("span", { children: /* @__PURE__ */ jsxs(
    Root,
    {
      ref: rootRef,
      "data-testid": testId,
      "data-tidal": toolbarButtonName,
      onClick,
      "aria-pressed": selected,
      hoverBulge,
      selected,
      showLabels: showLabel,
      ...rest,
      children: [
        /* @__PURE__ */ jsx(Icon, { className: toolbarButtonClasses.icon, children: /* @__PURE__ */ jsx(
          Badge,
          {
            className: toolbarButtonClasses.badge,
            anchorOrigin: badgeAnchorOrigin,
            color: "error",
            invisible: !indicator,
            overlap: "rectangular",
            variant: "dot",
            children: selected ? selectedIcon : icon
          }
        ) }),
        showLabel && /* @__PURE__ */ jsx(Label, { className: toolbarButtonClasses.label, children: label })
      ]
    }
  ) }) });
}
const badgeAnchorOrigin = {
  horizontal: "right",
  vertical: "top"
};
export {
  ToolbarButton
};
//# sourceMappingURL=ToolbarButton.js.map
