import { ButtonBase, alpha, styled, svgIconClasses } from "@mui/material";
import { toolbarButtonClasses, toolbarButtonName } from "../classes.js";
const excludedProps = ["hoverBulge", "showLabels", "selected"];
const Root = styled(ButtonBase, {
  name: toolbarButtonName,
  overridesResolver: (_props, styles) => [styles.root],
  shouldForwardProp: (prop) => !excludedProps.includes(prop),
  slot: "Root"
})(({ theme, hoverBulge, showLabels, selected }) => ({
  display: "flex",
  alignItems: "center",
  alignSelf: "center",
  color: theme.vars.palette.common.white,
  cursor: "pointer",
  flexDirection: "column",
  fontSize: theme.typography.caption.fontSize,
  gap: theme.spacing(0.75),
  height: theme.spacing(7),
  margin: `0 ${theme.spacing(1)}`,
  userSelect: "none",
  width: theme.spacing(7),
  "&:focus-within": {
    outline: "none"
  },
  "&:disabled": {
    color: alpha(theme.palette.common.white, theme.palette.action.disabledOpacity),
    cursor: "default",
    pointerEvents: "none"
  },
  [`& .${toolbarButtonClasses.icon}`]: {
    color: "inherit"
  },
  ...selected && {
    [`& .${toolbarButtonClasses.icon}`]: {
      backgroundColor: theme.vars.palette.primary.dark
    }
  },
  [`&:focus-within .${toolbarButtonClasses.icon}`]: {
    backgroundColor: alpha(theme.palette.tidalColors.oceanBlue[500], 0.3)
  },
  [`&:hover .${toolbarButtonClasses.icon}`]: {
    backgroundColor: alpha(theme.palette.tidalColors.oceanBlue[500], 0.5)
  },
  ...showLabels && {
    [`& .${toolbarButtonClasses.icon}`]: {
      borderRadius: "100px",
      height: theme.spacing(4)
    }
  },
  ...hoverBulge && {
    [`& .${svgIconClasses.root}`]: {
      transition: "transform 0.2s cubic-bezier(0.17, 0.67, 0.55, 1.09)"
    },
    [`&:hover .${svgIconClasses.root}`]: {
      transform: "scale(1.15)"
    }
  }
}));
export {
  Root
};
//# sourceMappingURL=Root.js.map
