import { jsx } from "react/jsx-runtime";
import { useCallback, useEffect, useMemo, useRef } from "react";
import { toolbarContext } from "./context.js";
function ToolbarContextProvider(props) {
  const { getAnchor, registerAnchor } = useAnchors();
  const { isActive, setViews, toggleView, views } = useViewsApi(props);
  const contextValue = useMemo(() => {
    return {
      getAnchor,
      registerAnchor,
      isActive,
      setViews,
      toggleView,
      views
    };
  }, [getAnchor, registerAnchor, isActive, setViews, toggleView, views]);
  return /* @__PURE__ */ jsx(toolbarContext.Provider, { value: contextValue, children: props.children });
}
function useViewsApi(props) {
  const { onChangeViews, views, matchView = defaultMatchView } = props;
  const toggleView = useCallback(
    (view) => {
      const viewsSet = new Set(views);
      viewsSet.has(view) ? viewsSet.delete(view) : viewsSet.add(view);
      onChangeViews(Array.from(viewsSet));
    },
    [onChangeViews, views]
  );
  const setViews = useCallback(
    (...views2) => {
      onChangeViews(views2);
    },
    [onChangeViews]
  );
  const isActive = useCallback(
    (view) => {
      return matchView(views, view);
    },
    [matchView, views]
  );
  return {
    views,
    toggleView,
    setViews,
    isActive
  };
}
function useAnchors() {
  const anchors = useRef({});
  const registerAnchor = useCallback((id, anchor) => {
    anchors.current[id] = anchor;
  }, []);
  const getAnchor = useCallback((id) => {
    if (Object.keys(anchors.current ?? {}).length === 0) return null;
    if (anchors.current[id]) {
      return anchors.current[id];
    }
    return null;
  }, []);
  useEffect(() => {
    return () => {
      anchors.current = {};
    };
  }, []);
  return {
    registerAnchor,
    getAnchor
  };
}
function defaultMatchView(currentViews, viewToMatch) {
  return currentViews.indexOf(viewToMatch) !== -1;
}
export {
  ToolbarContextProvider
};
//# sourceMappingURL=ToolbarContextProvider.js.map
