import { jsx } from "react/jsx-runtime";
import {
  Stack,
  alpha,
  avatarClasses,
  listItemButtonClasses,
  styled,
  svgIconClasses
} from "@mui/material";
import { useRef } from "react";
import tinycolor from "tinycolor2";
import { toolbarName } from "../../classes.js";
import { DEFAULT_RAIL_VIEW_ID } from "../../constants.js";
import { useToolbar } from "../../hooks/useToolbar.js";
import { ToolbarRailContext } from "./context/ToolbarRailContext.js";
function ToolbarRail(props) {
  const { anchorId = DEFAULT_RAIL_VIEW_ID, disableAutoRegisterAnchor, showLabels, ...stackProps } = props;
  const { registerAnchor } = useToolbar();
  const railRef = useRef(null);
  if (!disableAutoRegisterAnchor) {
    registerAnchor(anchorId, railRef.current);
  }
  return /* @__PURE__ */ jsx(ToolbarRailContext, { showLabels, children: /* @__PURE__ */ jsx(ToolbarRailComponent, { ...stackProps, ref: railRef }) });
}
const ToolbarRailComponent = styled(Stack, {
  name: toolbarName,
  slot: "Rail",
  shouldForwardProp: (prop) => prop !== "enableLastChildGroup" && prop !== "disableChildCustomization"
})(
  ({ theme, backgroundColor: bgColor, color: textColor, enableLastChildGroup, disableChildCustomization }) => {
    const backgroundColor = getColorIfValid(bgColor, theme.palette.workwaveBlue);
    const color = getColorIfValid(textColor, theme.palette.common.white);
    return {
      flexShrink: 0,
      paddingBottom: theme.spacing(3),
      paddingTop: theme.spacing(3),
      gap: theme.spacing(1),
      position: "relative",
      zIndex: theme.zIndex.drawer + 10,
      overflowY: "auto",
      overflowX: "hidden",
      backgroundColor,
      color,
      ...disableChildCustomization ? {} : {
        [`& .${svgIconClasses.root}`]: {
          color
        },
        [`& .${avatarClasses.root}`]: {
          backgroundColor: color,
          color: backgroundColor
        },
        [`& .${avatarClasses.root} .${svgIconClasses.root}`]: {
          color: backgroundColor
        },
        [`& .${listItemButtonClasses.root}.${listItemButtonClasses.selected}`]: {
          backgroundColor: alpha(color, theme.palette.action.selectedOpacity)
        },
        [`& .${listItemButtonClasses.root}:hover`]: {
          backgroundColor: alpha(color, theme.palette.action.hoverOpacity)
        },
        [`& .${listItemButtonClasses.root}:focus-within`]: {
          backgroundColor: alpha(color, theme.palette.action.focusOpacity)
        }
      },
      ...enableLastChildGroup && {
        "& > *:last-child": {
          marginTop: "auto"
        }
      }
    };
  }
);
function getColorIfValid(desired, fallback) {
  if (!desired) return fallback;
  const tColorInstance = tinycolor(desired);
  if (!tColorInstance.isValid()) {
    console.warn(`Invalid color, ${desired}. Return fallback color ${fallback}`);
    return fallback;
  }
  return desired;
}
export {
  ToolbarRail
};
//# sourceMappingURL=ToolbarRail.js.map
