import type { ActionBarItemProps } from '@workwave-tidal/core/components/ActionBar';
import type { CSSProperties, ImgHTMLAttributes, ReactElement, ReactNode } from 'react';
import type { MimeType } from './mimeType.js';
type Loading = {
    loading?: true;
    progress?: number;
} | {
    loading?: false;
    progress?: never;
};
type CoreProps = Loading & {
    /**
     * data-testid placed in the root element
     *
     * @default 'FilePreview'
     */
    testId?: string;
    /**
     * tooltip text used to wrap the root element
     */
    tooltip: string;
    /**
     * if true the component will be in the error state
     */
    error?: boolean;
    /**
     * if true the component will be in the loading state
     */
    disabled?: boolean;
    /**
     * if 'onHoverOrFocus' actions will appears when the component is in focus or then the mouse is over the root element
     * if the device is a touch device the actions will appears no matter the setting
     * @default 'onHoverOrFocus
     */
    actionsVisibility?: 'always' | 'onHoverOrFocus';
    /**
     * onClick event handler that will be attached to the root element
     */
    onClick?: () => void;
    /**
     * Array of action items that will be rendered in the ActionBar
     */
    actions?: ReactElement<ActionBarItemProps>[];
};
export type StandardFilePreviewProps = CoreProps & {
    variant: 'standard';
    /**
     * Icon that will be rendered in the left side of the component
     */
    icon: ReactNode;
    /**
     * Title that will be displayed in the component, if it's a string it will be wrapped in a FilePreviewTitle component
     */
    title: ReactNode;
    /**
     * Subtitle that will be displayed in the component, if it's a string it will be wrapped in a FilePreviewSubtitle component
     */
    subtitle: ReactNode;
    /**
     * if specified it will replace the subtitle when the component is in hover or focus state
     * if it's a string it will be wrapped in a FilePreviewSubtitle component
     */
    hoverSubtitle?: ReactNode;
};
export type AllowedImageAttributes = Pick<ImgHTMLAttributes<HTMLImageElement>, 'alt' | 'crossOrigin' | 'decoding' | 'referrerPolicy' | 'sizes' | 'src' | 'srcSet'>;
export type ImageFilePreviewProps = CoreProps & AllowedImageAttributes & {
    variant: 'image';
    /**
     * size of the component
     */
    size: 'small' | 'medium' | 'large';
    /**
     * Object fit property of the image
     */
    objectFit?: CSSProperties['objectFit'];
    /**
     * If defined this title will be displayed below the progress.
     * Not rendered when the size is small
     */
    progressTitle?: string;
};
export type FilePreviewProps = StandardFilePreviewProps | ImageFilePreviewProps;
export type MimeTypeOrDefault = MimeType | 'default';
export type FilePreviewThumbnailProps = AllowedImageAttributes & {
    /**
     * @default 'contain'
     */
    objectFit?: CSSProperties['objectFit'];
};
export {};
//# sourceMappingURL=types.d.ts.map