import type { CSSProperties, ReactElement } from 'react';
export type CompactType = 'vertical' | 'horizontal' | null;
export type Size = {
    width: number;
    height: number;
};
export type PositionCoordinates = {
    left: number;
    top: number;
};
export type Position = PositionCoordinates & {
    width: number;
    height: number;
};
export type PositionParams = {
    columns: number;
    containerPadding: GridSpacing;
    containerWidth: number;
    margin: GridSpacing;
    maxRows: number;
    rowHeight: number;
};
export type Layout = LayoutItem[];
export type GridSpacing = [x: number, y: number];
export type LayoutItem = {
    height: number;
    id: string;
    isBounded?: boolean;
    isDraggable?: boolean;
    isStatic?: boolean;
    maxHeight?: number;
    maxWidth?: number;
    minHeight?: number;
    minWidth?: number;
    moved?: boolean;
    width: number;
    x: number;
    y: number;
};
export type GridDimensions = {
    columns: number;
    containerPadding?: GridSpacing;
    rowHeight: number;
    transformScale?: number;
    margin?: GridSpacing;
    maxRows?: number;
    width?: number;
};
export type MasonryProps = Partial<GridDimensions> & {
    children: ReactElement[];
    initialLayout?: Layout;
    style?: CSSProperties;
    allowOverlap?: boolean;
    autoHeight?: boolean;
    compactType?: CompactType;
    isDraggable?: boolean;
    isResizable?: boolean;
    isBounded?: boolean;
    preventCollision?: boolean;
    verticalCompact?: boolean;
    width?: number;
};
export type DefaultMasonryProps = Required<Omit<MasonryProps, 'width'>>;
export type MasonryItemProps = Required<GridDimensions> & LayoutItem & {
    columns: number;
    rowHeight: number;
    children: ReactElement;
    className?: string;
    containerWidth: number;
    onDragStart?: DragEventCallback;
    onDrag?: DragEventCallback;
    onDragStop?: DragEventCallback;
};
export type MasonryDragEvent = {
    e: Event;
    node: HTMLElement;
    newPosition: PositionCoordinates;
};
export type MasonryResizeEvent = {
    e: Event;
    node: HTMLElement;
    size: Size;
    handle: string;
};
export type DragEventCallback = (id: string, x: number, y: number) => void;
//# sourceMappingURL=types.d.ts.map