import type { ButtonBaseProps, SxProps, Theme, TooltipProps } from '@mui/material';
import type { MouseEventHandler, ReactNode } from 'react';
export type UseToolbarButtonProps = {
    /**
     * The icon to display in the button
     */
    icon: ReactNode;
    /**
     * Manual override of the selected state of the button
     */
    selected?: boolean;
} & ({
    onClick?: never;
    /**
     * The icon to display in the button when a button is selected
     */
    selectedIcon: ReactNode;
    /**
     * A string that identifies the view that the button will set as active
     */
    value: string;
} | {
    /**
     * Click handler that fires when a button is not connected to a view
     */
    onClick: MouseEventHandler<HTMLButtonElement>;
    selectedIcon?: ReactNode;
    value?: never;
});
export type ToolbarButtonProps = ButtonBaseProps & UseToolbarButtonProps & {
    /**
     * Allows defining system overrides and additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Additional class(es) applied to the root component.
     */
    className?: string;
    /**
     * `data-testid` attribute applied to the root component
     */
    testId?: string;
    /**
     * Controls the bulging hover effect of the button's icon
     */
    hoverBulge?: boolean;
    /**
     * Controls the display of the indicator/badge
     */
    indicator?: boolean;
    /**
     * The text label below the icon; serves as the default tooltip/a11y
     * attributes when using icon-only button
     */
    label: string;
    /**
     * The text content of the Tooltip
     */
    tooltip?: TooltipProps['title'];
    /**
     * Tooltip placement
     */
    tooltipPlacement?: TooltipProps['placement'];
    /**
     * if defined the DOM reference of the button will be registered within the anchorId in the map
     */
    anchorId?: string;
    /**
     * Will override the showLabels from the context, used to customize only a subset of buttons inside the Rail
     */
    showLabel?: boolean;
};
//# sourceMappingURL=types.d.ts.map